/* Copyright 1999-2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef APACHE_PASSWD_H
#define APACHE_PASSWD_H

#ifdef WIN32

#include <stdlib.h>

struct passwd
{
    char pw_dir[_MAX_PATH];
};

struct passwd *getpwnam(const char *szUser);

#endif /* WIN32 */

#endif /* ndef APACHE_PASSWD_H */
